@@ -453,7 +453,7 @@ camel_ews_folder_get_message (CamelFolder *folder,
 
 	res = e_ews_connection_get_items_sync (
 		cnc, pri, ids, "IdOnly", "item:MimeContent",
-		TRUE, mime_dir,
+		TRUE, mime_dir, E_EWS_BODY_TYPE_ANY,
 		&items,
 		(ESoapProgressFn) camel_operation_progress,
 		(gpointer) cancellable,
@@ -486,7 +486,7 @@ camel_ews_folder_get_message (CamelFolder *folder,
 		res = e_ews_connection_get_items_sync (
 			cnc, pri, ids, "IdOnly",
 			"meeting:AssociatedCalendarItemId",
-			FALSE, NULL,
+			FALSE, NULL, E_EWS_BODY_TYPE_ANY,
 			&items_req,
 			(ESoapProgressFn) camel_operation_progress,
 			(gpointer) cancellable,
@@ -571,6 +571,38 @@ exit:
 	return message;
 }
 
+static void
+ews_folder_maybe_update_mlist (CamelFolder *folder,
+			       const gchar *uid,
+			       CamelMimeMessage *message)
+{
+	CamelEwsMessageInfo *mi;
+
+	g_return_if_fail (CAMEL_IS_FOLDER (folder));
+	g_return_if_fail (uid != NULL);
+	g_return_if_fail (message != NULL);
+
+	mi = (CamelEwsMessageInfo *) camel_folder_summary_get (folder->summary, uid);
+	if (!mi)
+		return;
+
+	if (!mi->info.mlist || !*mi->info.mlist) {
+		/* update mailing list information, if necessary */
+		gchar *mlist = camel_header_raw_check_mailing_list (&(CAMEL_MIME_PART (message)->headers));
+
+		if (mlist) {
+			if (mi->info.mlist)
+				camel_pstring_free (mi->info.mlist);
+			mi->info.mlist = camel_pstring_add (mlist, TRUE);
+			mi->info.dirty = TRUE;
+
+			camel_folder_summary_touch (folder->summary);
+		}
+	}
+
+	camel_message_info_free ((CamelMessageInfo *) mi);
+}
+
 /* Get the message from cache if available otherwise get it from server */
 static CamelMimeMessage *
 ews_folder_get_message_sync (CamelFolder *folder,
@@ -581,8 +613,10 @@ ews_folder_get_message_sync (CamelFolder *folder,
 	CamelMimeMessage *message;
 
 	message = camel_ews_folder_get_message_from_cache ((CamelEwsFolder *) folder, uid, cancellable, NULL);
-	if (!message)
+	if (!message) {
 		message = camel_ews_folder_get_message (folder, uid, EWS_ITEM_HIGH, cancellable, error);
+		ews_folder_maybe_update_mlist (folder, uid, message);
+	}
 
 	return message;
 }
@@ -1230,7 +1264,7 @@ sync_updated_items (CamelEwsFolder *ews_folder,
 		e_ews_connection_get_items_sync (
 			cnc, EWS_PRIORITY_MEDIUM,
 			msg_ids, "IdOnly", SUMMARY_MESSAGE_FLAGS,
-			FALSE, NULL, &items, NULL, NULL,
+			FALSE, NULL, E_EWS_BODY_TYPE_ANY, &items, NULL, NULL,
 			cancellable, &local_error);
 
 	camel_ews_utils_sync_updated_items (ews_folder, items);
@@ -1245,7 +1279,7 @@ sync_updated_items (CamelEwsFolder *ews_folder,
 		e_ews_connection_get_items_sync (
 			cnc, EWS_PRIORITY_MEDIUM,
 			generic_item_ids, "IdOnly", SUMMARY_ITEM_FLAGS,
-			FALSE, NULL, &items, NULL, NULL,
+			FALSE, NULL, E_EWS_BODY_TYPE_ANY, &items, NULL, NULL,
 			cancellable, &local_error);
 	camel_ews_utils_sync_updated_items (ews_folder, items);
 
@@ -1313,7 +1347,7 @@ sync_created_items (CamelEwsFolder *ews_folder,
 		e_ews_connection_get_items_sync (
 			cnc, EWS_PRIORITY_MEDIUM,
 			msg_ids, "IdOnly", SUMMARY_MESSAGE_PROPS,
-			FALSE, NULL, &items, NULL, NULL,
+			FALSE, NULL, E_EWS_BODY_TYPE_ANY, &items, NULL, NULL,
 			cancellable, &local_error);
 
 	if (local_error) {
@@ -1329,7 +1363,7 @@ sync_created_items (CamelEwsFolder *ews_folder,
 		e_ews_connection_get_items_sync (
 			cnc, EWS_PRIORITY_MEDIUM,
 			post_item_ids, "IdOnly", SUMMARY_POSTITEM_PROPS,
-			FALSE, NULL, &items, NULL, NULL,
+			FALSE, NULL, E_EWS_BODY_TYPE_ANY, &items, NULL, NULL,
 			cancellable, &local_error);
 
 	if (local_error) {
@@ -1345,7 +1379,7 @@ sync_created_items (CamelEwsFolder *ews_folder,
 		e_ews_connection_get_items_sync (
 			cnc, EWS_PRIORITY_MEDIUM,
 			generic_item_ids, "IdOnly", SUMMARY_ITEM_PROPS,
-			FALSE, NULL, &items, NULL, NULL,
+			FALSE, NULL, E_EWS_BODY_TYPE_ANY, &items, NULL, NULL,
 			cancellable, &local_error);
 
 	camel_ews_utils_sync_created_items (ews_folder, cnc, items, cancellable);
