@@ -236,8 +236,7 @@ add_folder_to_summary (CamelEwsStore *store,
 
 static void
 sync_created_folders (CamelEwsStore *ews_store,
-                      GSList *created_folders,
-		      GSList **created_folder_ids)
+                      GSList *created_folders)
 {
 	GSList *l;
 
@@ -260,12 +259,7 @@ sync_created_folders (CamelEwsStore *ews_store,
 		 * let's worry about that in a later commit. */
 		add_folder_to_summary (ews_store, folder);
 
-		if (ftype != E_EWS_FOLDER_TYPE_MAILBOX)
-			continue;
-
-		if (created_folder_ids) {
-			*created_folder_ids = g_slist_append (*created_folder_ids, g_strdup (fid->id));
-		} else {
+		if (ftype == E_EWS_FOLDER_TYPE_MAILBOX) {
 			fi = camel_ews_utils_build_folder_info (
 				ews_store, fid->id);
 			camel_store_folder_created (
@@ -281,14 +275,13 @@ void
 ews_utils_sync_folders (CamelEwsStore *ews_store,
                         GSList *created_folders,
                         GSList *deleted_folders,
-                        GSList *updated_folders,
-			GSList **created_folder_ids)
+                        GSList *updated_folders)
 {
 	GError *error = NULL;
 
 	sync_deleted_folders (ews_store, deleted_folders);
 	sync_updated_folders (ews_store, updated_folders);
-	sync_created_folders (ews_store, created_folders, created_folder_ids);
+	sync_created_folders (ews_store, created_folders);
 
 	camel_ews_store_summary_save (ews_store->summary, &error);
 	if (error != NULL) {
@@ -720,7 +713,7 @@ camel_ews_utils_sync_created_items (CamelEwsFolder *ews_folder,
 		}
 
 		item_type = e_ews_item_get_item_type (item);
-		if (item_type == E_EWS_ITEM_TYPE_CALENDAR_ITEM ||
+		if (item_type == E_EWS_ITEM_TYPE_EVENT ||
 			 item_type == E_EWS_ITEM_TYPE_MEETING_MESSAGE ||
 			 item_type == E_EWS_ITEM_TYPE_MEETING_REQUEST ||
 			 item_type == E_EWS_ITEM_TYPE_MEETING_RESPONSE ||
